
from fastapi import  FastAPI
from fastapi.middleware.cors import CORSMiddleware

from app.models.database import  engine, Base

import app.routers.job_jdbc_datasource as router_jjds
import app.routers.constants as router_constants
import app.routers.job_info as router_job_info
import app.routers.datax_json as router_datax

Base.metadata.create_all(bind=engine)
app = FastAPI( docs_url='/jpt/docs', redoc_url='/jpt/redoc', title="DAG管理系统")

# CORS 跨源资源共享
app.add_middleware(
    CORSMiddleware,
    allow_origins=["*"],
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)



app.include_router(router_jjds.router)
app.include_router(router_constants.router)
app.include_router(router_job_info.router)
app.include_router(router_datax.router)


# Get 健康检查
@app.get("/ping", description="健康检查")
def ping():
    return "pong!"



if __name__ == '__main__':
    import uvicorn
    import argparse

    parser = argparse.ArgumentParser()
    parser.add_argument('--host', default='0.0.0.0')
    parser.add_argument('--port', default=8080)
    opt = parser.parse_args()

    app_str = 'server:app'  # make the app string equal to whatever the name of this file is
    uvicorn.run(app_str, host=opt.host, port=int(opt.port), reload=True)
